@@ -26,9 +26,9 @@ sub new
 sub _initialize
 {
     my $self = shift;
-    my (%args) = @_;
-    $self->Verbose($args{Verbose});
-    $self->NoTty($args{NoTty});
+    my $args = shift;
+    $self->Verbose($args->{Verbose});
+    $self->NoTty($args->{NoTty});
     return 0;
 }
 
@@ -48,18 +48,26 @@ sub print_message
 {
     my ($self, $msg) = @_;
     $self->_print_message_raw($msg);
-    print "\n";
+    $self->_newline();
+
+}
+
+sub _newline
+{
+    my $self = shift;
+    $self->_print_message_raw("\n");
 }
 
 sub print_leader
 {
-    my $self = shift;
-    my (%args) = @_;
+    my ($self, $args) = @_;
+
     my ($leader, $ml) =
         $self->_mk_leader(
-            $args{filename},
-            $args{width},
+            $args->{filename},
+            $args->{width},
         );
+
     $self->ml($ml);
     $self->_print_message_raw(
         $leader,
@@ -99,7 +107,8 @@ The C<$width> is the width of the "yada/blah.." string.
 
 =cut
 
-sub _mk_leader {
+sub _mk_leader
+{
     my ($self, $te, $width) = @_;
     chomp($te);
     $te =~ s/\.\w+$/./;
@@ -110,8 +119,9 @@ sub _mk_leader {
     my $leader = "$te" . '.' x ($width - length($te));
     my $ml = "";
 
-    if ( -t STDOUT and not $self->NoTty() and not $self->Verbose()) {
-        $ml = "\r" . (' ' x 77) . "\r$leader"
+    if ( -t STDOUT and not $self->NoTty() and not $self->Verbose())
+    {
+        $ml = "\r" . (' ' x 77) . "\r$leader";
     }
 
     return($leader, $ml);
