@@ -2,18 +2,18 @@
 package Test::Run::Straps;
 
 use strict;
-use vars qw($VERSION @ISA);
-$VERSION = '0.24';
+use vars qw($VERSION);
+$VERSION = '0.25';
 
 use Config;
 use TAP::Parser;
 use List::Util qw(first);
 
 use Test::Run::Base;
-use Test::Run::Assert;
-use Test::Run::Obj::Structs;
 
-@ISA = (qw(Test::Run::Base::Struct));
+use base 'Test::Run::Base::Struct';
+
+use Test::Run::Straps::StrapsTotalsObj;
 
 my @fields= (qw(
     bailout_reason
@@ -162,16 +162,13 @@ sub _init_totals_obj_instance
     return Test::Run::Straps::StrapsTotalsObj->new($args);
 }
 
-sub _init_details_obj_instance
-{
-    my ($self, $args) = @_;
-    return Test::Run::Straps::StrapsDetailsObj->new($args);
-}
-
 sub _get_initial_totals_obj_params
 {
+    my $self = shift;
+
     return
     {
+        filename => $self->file(),
         max      => 0,
         seen     => 0,
 
@@ -311,31 +308,6 @@ sub _is_event_pass
     );
 }
 
-sub _update_details
-{
-    my $self = shift;
-
-    my $event = $self->_event;
-
-    my $details =
-        $self->_init_details_obj_instance(
-            {
-                ok          => $self->_is_event_pass(),
-                actual_ok   => _def_or_blank(scalar($event->is_ok())),
-                name        => _def_or_blank( $event->description ),
-                # $event->directive returns "SKIP" or "TODO" in uppercase
-                # and we expect them to be in lowercase.
-                type        => lc(_def_or_blank( $event->directive )),
-                reason      => _def_or_blank( $event->explanation ),
-            },
-        );
-
-    assert( defined( $details->ok() ) && defined( $details->actual_ok() ) );
-    $self->_file_totals->details()->[$event->number - 1] = $details;
-
-    return;
-}
-
 sub _handle_comment_event
 {
     my $self = shift;
@@ -349,18 +321,6 @@ sub _handle_comment_event
     return;
 }
 
-sub _is_enormous_event_num
-{
-    my $self = shift;
-
-    return 
-    (
-        ($self->_event->number > 100_000)
-            &&
-        ($self->_event->number > ($self->max()||100_000))
-    )
-}
-
 sub _handle_enormous_event_num
 {
     my $self = shift;
@@ -373,61 +333,11 @@ sub _handle_enormous_event_num
     }
 }
 
-sub _update_details_wrapper
-{
-    my $self = shift;
-
-    my $event = $self->_event;
-
-    if ($self->_is_enormous_event_num())
-    {
-        $self->_handle_enormous_event_num();
-    }
-    else
-    {
-        $self->_update_details();
-    }
-}
 
 sub _handle_labeled_test_event
 {
     my $self = shift;
 
-    my $event = $self->_event;
-    my $totals = $self->_file_totals();
-
-    if ($self->_is_event_todo())
-    {
-        $totals->inc_field('todo');
-        if ( $event->is_actual_ok() )
-        {
-            $totals->inc_field('bonus');
-        }
-    }
-    elsif ( $event->has_skip ) {
-        $totals->inc_field('skip');
-    }
-
-    return;
-}
-
-sub _update_if_pass
-{
-    my $self = shift;
-
-    if ($self->_is_event_pass())
-    {
-        $self->_file_totals->inc_field('ok');
-    }
-
-    return;
-}
-
-sub _inc_seen
-{
-    my $self = shift;
-
-    $self->_file_totals->inc_field('seen');
 }
 
 sub _inc_seen_header
@@ -440,11 +350,13 @@ sub _inc_seen_header
 sub _handle_test_event
 {
     my $self = shift;
-
-    $self->_inc_seen();
-    $self->_handle_labeled_test_event();
-    $self->_update_if_pass();
-    $self->_update_details_wrapper();
+    return $self->_file_totals->handle_event(
+        {
+            event => $self->_event,
+            enormous_num_cb =>
+                sub { return $self->_handle_enormous_event_num(); },
+        }
+    );
 
     return;
 }
@@ -956,9 +868,5 @@ L<Test::Run>
 
 =cut
 
-sub _def_or_blank {
-    return $_[0] if defined $_[0];
-    return "";
-}
 
 1;
